==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/sr.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Документи",
"Can't create document" => "Не могу да направим документ",
"You don't have permission to rename this document" => "Немате дозволе да преименујете овај документ",
"Directory saved successfully." => "Директоријум успешно сачуван.",
"An error occurred while changing directory." => "Дошло је до грешке при мењању директоријума.",
"Saved" => "Сачуван",
"Format filter server is down or misconfigured" => "Сервер филтера формата је недоступан или лоше подешен",
"Conversion failed. Check log for details." => "Претварање неуспешно. За детаље, погледајте записник.",
"Saving..." => "Уписујем...",
"Failed to load documents." => "Не могу да учитам документе.",
"No documents were found. Upload or create a document to get started!" => "Нису пронађени документи. Отпремите или направите документ да почнете!",
"No connection to server. Trying to reconnect." => "Нема везе са сервером. Покушавам поновно повезивање.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Остављање ове странице у режиму уређивача може довести до несачуваних података. Користите дугме „Затвори“.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Не могу да учитам овај документ. Проверите може ли се отворити спољашњим .odt уређивачем. Ово може значити и да се више не дели или је недавно обрисан.",
"Save" => "Сачувај",
"Loading documents..." => "Учитавам документе...",
"'.' is an invalid file name." => "„.“ није исправан назив фајла.",
"File name cannot be empty." => "Назив фајла не може бити празан.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Неисправан назив. Следећи знакови нису дозвољени: \\, /, <, >, :, \", |, ? и *.",
"Align Left" => "Поравнај лево",
"Alignment" => "Поравнање",
"Align Right" => "Поравнај десно",
"Annotate" => "Нотирај",
"Background" => "Позадина",
"Bold" => "Подебљано",
"Bottom" => "Дно",
"Cancel" => "Откажи",
"Center" => "Центрирај",
"Clone" => "Клонирај",
"Clone this Style" => "Клонирај овај стил",
"Close" => "Затвори",
"Color" => "Боја",
"Create" => "Направи",
"Decrease Indent" => "Смањи увлачење",
"Default Style" => "Подразумевани стил",
"Delete" => "Обриши",
"Family" => "Фамилија",
"Font" => "Фонт",
"Font Effects" => "Ефекти фонта",
"Format" => "Формат",
"Increase Indent" => "Повећај увлачење",
"Insert Image" => "Убаци слику",
"Invite Members" => "Позови чланове",
"Italic" => "Курзив",
"Justified" => "Обострано поравнато",
"Justify" => "Обострано поравнај",
"Left" => "Лево",
"Loading" => "Учитавам",
"Members" => "Чланови",
"New Name:" => "Нови назив:",
"OK" => "У реду",
"Open" => "Отвори",
"Options" => "Опције",
"Paragraph..." => "Пасус...",
"Paragraph Styles" => "Стилови пасуса",
"Redo" => "Понови",
"Right" => "Десно",
"Size" => "Величина",
"Spacing" => "Размак",
"Strikethrough" => "Прецртано",
"Style" => "Стил",
"Text" => "Текст",
"Top" => "Врх",
"Underline" => "Подвучено",
"Undo" => "Врати",
"Unknown Author" => "Непознат аутор",
"Edit" => "Уреди",
"Share" => "Дели",
"guest" => "гост",
"MS Word support (requires openOffice/libreOffice)" => "Подршка за MS Word (захтева openOffice/libreOffice)",
"Local" => "локална",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice је инсталиран на овом серверу. Путања до програма добија се из preview_libreoffice_path in config.php",
"External" => "спољашња",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice је инсталиран на спољашњем серверу који покреће сервер филтера формата",
"Disabled" => "искључена",
"No MS Word support" => "Без подршке за MS Word",
"scheme://domain.tld[:port]" => "облик://домен.tld[:порт]",
"Server URL" => "УРЛ сервера",
"Apply and test" => "Примени и тестирај",
"New document" => "Нови документ",
"Upload (max. %s)" => "Отпремање (макс. %s)",
"Upload" => "Отпреми",
"Save new documents to" => "Сачувај нове документе у",
"Wrong password. Please retry." => "Погрешна лозинка. Покушајте поново.",
"Password" => "Лозинка",
"Guest %s" => "Гост %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Овај линк је истекао или није ни постојао. Контактирајте особу која ју је поделила са вама.",
"Advanced feature-set" => "Напредне опције",
"(Unstable)" => "(Нестабилно)"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";

==> owncloud-app-documents-1%3A9.1.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/sr.php <==
<?php
$TRANSLATIONS = array(
"Documents" => "Документи",
"Can't create document" => "Не могу да направим документ",
"You don't have permission to rename this document" => "Немате дозволе да преименујете овај документ",
"Directory saved successfully." => "Директоријум успешно сачуван.",
"An error occurred while changing directory." => "Дошло је до грешке при мењању директоријума.",
"Saved" => "Сачуван",
"Format filter server is down or misconfigured" => "Сервер филтера формата је недоступан или лоше подешен",
"Conversion failed. Check log for details." => "Претварање неуспешно. За детаље, погледајте записник.",
"Saving..." => "Уписујем...",
"Failed to load documents." => "Не могу да учитам документе.",
"No documents were found. Upload or create a document to get started!" => "Нису пронађени документи. Отпремите или направите документ да почнете!",
"No connection to server. Trying to reconnect." => "Нема везе са сервером. Покушавам поновно повезивање.",
"Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." => "Остављање ове странице у режиму уређивача може довести до несачуваних података. Користите дугме „Затвори“.",
"Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." => "Не могу да учитам овај документ. Проверите може ли се отворити спољашњим .odt уређивачем. Ово може значити и да се више не дели или је недавно обрисан.",
"Save" => "Сачувај",
"Loading documents..." => "Учитавам документе...",
"'.' is an invalid file name." => "„.“ није исправан назив фајла.",
"File name cannot be empty." => "Назив фајла не може бити празан.",
"Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." => "Неисправан назив. Следећи знакови нису дозвољени: \\, /, <, >, :, \", |, ? и *.",
"Align Left" => "Поравнај лево",
"Alignment" => "Поравнање",
"Align Right" => "Поравнај десно",
"Annotate" => "Нотирај",
"Background" => "Позадина",
"Bold" => "Подебљано",
"Bottom" => "Дно",
"Cancel" => "Откажи",
"Center" => "Центрирај",
"Clone" => "Клонирај",
"Clone this Style" => "Клонирај овај стил",
"Close" => "Затвори",
"Color" => "Боја",
"Create" => "Направи",
"Decrease Indent" => "Смањи увлачење",
"Default Style" => "Подразумевани стил",
"Delete" => "Обриши",
"Family" => "Фамилија",
"Font" => "Фонт",
"Font Effects" => "Ефекти фонта",
"Format" => "Формат",
"Increase Indent" => "Повећај увлачење",
"Insert Image" => "Убаци слику",
"Invite Members" => "Позови чланове",
"Italic" => "Курзив",
"Justified" => "Обострано поравнато",
"Justify" => "Обострано поравнај",
"Left" => "Лево",
"Loading" => "Учитавам",
"Members" => "Чланови",
"New Name:" => "Нови назив:",
"OK" => "У реду",
"Open" => "Отвори",
"Options" => "Опције",
"Paragraph..." => "Пасус...",
"Paragraph Styles" => "Стилови пасуса",
"Redo" => "Понови",
"Right" => "Десно",
"Size" => "Величина",
"Spacing" => "Размак",
"Strikethrough" => "Прецртано",
"Style" => "Стил",
"Text" => "Текст",
"Top" => "Врх",
"Underline" => "Подвучено",
"Undo" => "Врати",
"Unknown Author" => "Непознат аутор",
"Shared" => "Дељено",
"Error" => "Грешка",
"Error while sharing" => "Грешка при дељењу",
"Error while unsharing" => "Грешка при укидању дељења",
"Error while changing permissions" => "Грешка при измени дозвола",
"Shared with you and the group {group} by {owner}" => "{owner} дели са вама и са групом {group}.",
"Shared with you by {owner}" => "{owner} дели са вама",
"Share with users or groups …" => "Дели са корисницима или групама...",
"Share with users, groups or remote users …" => "Дели са корисницима, групама или удаљеним корисницима...",
"Share" => "Дели",
"Share with people on other ownClouds using the syntax username@example.com/owncloud" => "Поделите са људима у другим облацима користећи синтаксу корисничкоиме@сервер.com/owncloud",
"Share link" => "Веза дељења",
"The public link will expire no later than {days} days after it is created" => "Јавна веза ће престати да важи {days} дана након стварања",
"Link" => "Веза",
"Password protect" => "Заштићено лозинком",
"Password" => "Лозинка",
"Choose a password for the public link" => "Одредите лозинку за јавну везу",
"Allow editing" => "Дозволи уређивање",
"Email link to person" => "Пошаљи е-поштом",
"Send" => "Пошаљи",
"Set expiration date" => "Постави датум истека",
"Expiration" => "Истиче",
"Expiration date" => "Датум истека",
"An error occured. Please try again" => "Дошло је до грешке. Покушајте поново",
"Adding user..." => "Додајем корисника...",
"group" => "група",
"remote" => "удаљени",
"Resharing is not allowed" => "Поновно дељење није дозвољено",
"Shared in {item} with {user}" => "Подељено унутар {item} са корисником {user}",
"Unshare" => "Не дели",
"notify by email" => "обавести е-поштом",
"can share" => "може да дели",
"can edit" => "може да мења",
"access control" => "права приступа",
"create" => "направи",
"change" => "измени",
"delete" => "обриши",
"Password protected" => "Заштићено лозинком",
"Error unsetting expiration date" => "Грешка при поништавању датума истека",
"Error setting expiration date" => "Грешка при постављању датума истека",
"Sending ..." => "Шаљем...",
"Email sent" => "Порука је послата",
"Warning" => "Упозорење",
"Edit" => "Уреди",
"guest" => "гост",
"MS Word support (requires openOffice/libreOffice)" => "Подршка за MS Word (захтева openOffice/libreOffice)",
"Local" => "локална",
"openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" => "openOffice/libreOffice је инсталиран на овом серверу. Путања до програма добија се из preview_libreoffice_path in config.php",
"External" => "спољашња",
"openOffice/libreOffice is installed on external server running a format filter server" => "openOffice/libreOffice је инсталиран на спољашњем серверу који покреће сервер филтера формата",
"Disabled" => "искључена",
"No MS Word support" => "Без подршке за MS Word",
"scheme://domain.tld[:port]" => "облик://домен.tld[:порт]",
"Server URL" => "УРЛ сервера",
"Apply and test" => "Примени и тестирај",
"New document" => "Нови документ",
"Upload (max. %s)" => "Отпремање (макс. %s)",
"Upload" => "Отпреми",
"Save new documents to" => "Сачувај нове документе у",
"Wrong password. Please retry." => "Погрешна лозинка. Покушајте поново.",
"Guest %s" => "Гост %s",
"This link has been expired or is never existed. Please contact the person who shared it with you for details." => "Овај линк је истекао или није ни постојао. Контактирајте особу која ју је поделила са вама.",
"Advanced feature-set" => "Напредне опције",
"(Unstable)" => "(Нестабилно)"
);
$PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
